@@ -23,6 +23,7 @@
 #include <gtkmm/dialog.h>
 #include <gtkmm/treeview.h>
 #include <gtkmm/liststore.h>
+#include <gtkmm/image.h>
 
 namespace GParted
 {
@@ -38,6 +39,8 @@ public:
 private:
 	void show_filesystem( const FS & fs ) ;
 
+	Gtk::HBox *hbox ;
+	Gtk::Image *image ;
 	Gtk::TreeView treeview_filesystems;
 	Gtk::TreeRow treerow;
 	Glib::RefPtr<Gtk::ListStore> liststore_filesystems;
@@ -53,6 +56,7 @@ private:
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > move ;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > copy ;
 		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > check ;
+		Gtk::TreeModelColumn< Glib::RefPtr<Gdk::Pixbuf> > read_label ;
 				
 		treeview_filesystems_Columns() 
 		{ 
@@ -65,6 +69,7 @@ private:
 			add( move ) ;
 			add( copy ) ;
 			add( check ) ;
+			add( read_label ) ;
 		}
 	};
 	
