@@ -19,42 +19,18 @@
 #define OPERATION
 
 #include "../include/Device.h"
+#include "../include/OperationDetail.h"
 
 namespace GParted
 {
-		
+	//FIXME: stop using GParted:: in front of our own enums.. it's not necessary and clutters the code
 enum OperationType {
-        DELETE		= 0,
-	CREATE		= 1,
-	RESIZE_MOVE	= 2,
-	FORMAT		= 3,
-	COPY		= 4
-};
-
-struct OperationDetails
-{
-	enum Status {
-		NONE	= -1,
-		EXECUTE	= 0,
-		SUCCES	= 1,
-		ERROR	= 2
-	};
-	
-	OperationDetails()
-	{
-		status = NONE ;
-	}
-
-	OperationDetails( const Glib::ustring & description, Status status = EXECUTE )
-	{
-		this ->description = description ;
-		this ->status = status ;
-	}
-
-	Glib::ustring description ;
-	Status status ; 
-
-	std::vector<OperationDetails> sub_details ; 	
+        OPERATION_DELETE	= 0,
+	OPERATION_CHECK		= 1,
+	OPERATION_CREATE	= 2,
+	OPERATION_RESIZE_MOVE	= 3,
+	OPERATION_FORMAT	= 4,
+	OPERATION_COPY		= 5
 };
 
 class Operation
@@ -65,6 +41,7 @@ public:
 	virtual ~Operation() {}
 	
 	virtual void apply_to_visual( std::vector<Partition> & partitions ) = 0 ;
+	virtual void create_description() = 0 ;
 
 	//public variables
 	Device device ;
@@ -75,15 +52,13 @@ public:
 	Glib::RefPtr<Gdk::Pixbuf> icon ;
 	Glib::ustring description ;
 
-	OperationDetails operation_details ;
+	OperationDetail operation_detail ;
 
 protected:
 	int find_index_original( const std::vector<Partition> & partitions ) ;
 	int find_index_extended( const std::vector<Partition> & partitions ) ;
 	void insert_unallocated( std::vector<Partition> & partitions, Sector start, Sector end, bool inside_extended );
 	
-	virtual void create_description() = 0 ;
-
 	int index ;
 	int index_extended ;
 };
