@@ -27,13 +27,15 @@ namespace GParted
 class ext2 : public FileSystem
 {
 public:
-	FS get_filesystem_support( ) ;
-	void Set_Used_Sectors( Partition & partition ) ;
-	bool Create( const Partition & new_partition ) ;
-	bool Resize( const Partition & partition_new, bool fill_partition = false ) ;
-	bool Copy( const Glib::ustring & src_part_path, const Glib::ustring & dest_part_path ) ;
-	bool Check_Repair( const Partition & partition ) ;
-	int get_estimated_time( long MB_to_Consider ) ;
+	FS get_filesystem_support() ;
+	void set_used_sectors( Partition & partition ) ;
+	void get_label( Partition & partition ) ;
+	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
+	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
+	bool copy( const Glib::ustring & src_part_path,
+		   const Glib::ustring & dest_part_path,
+		   OperationDetail & operationdetail ) ;
+	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
 };
 
 } //GParted
