@@ -27,7 +27,7 @@ DialogFeatures::DialogFeatures()
 	set_title( _("Features") ) ;
 	set_has_separator( false ) ;
 	set_resizable( false ) ;
-	
+
 	liststore_filesystems = Gtk::ListStore::create( treeview_filesystems_columns );
 	treeview_filesystems .set_model( liststore_filesystems );
 	treeview_filesystems .append_column( _("Filesystem"), treeview_filesystems_columns .filesystem );
@@ -39,9 +39,29 @@ DialogFeatures::DialogFeatures()
 	treeview_filesystems .append_column( _("Move"), treeview_filesystems_columns .move );
 	treeview_filesystems .append_column( _("Copy"), treeview_filesystems_columns .copy );
 	treeview_filesystems .append_column( _("Check"), treeview_filesystems_columns .check );
-		
+	treeview_filesystems .append_column( _("Read Label"), treeview_filesystems_columns .read_label );
+	//FIXME: add info about the relevant project (e.g an url to the projectpage)
+	//of course this url has to be selectable and (if possible) clickable
 	treeview_filesystems .get_selection() ->set_mode( Gtk::SELECTION_NONE );
-	get_vbox() ->pack_start( treeview_filesystems ) ;
+	treeview_filesystems .set_rules_hint( true ) ;
+
+	hbox = manage( new Gtk::HBox() ) ;
+	hbox ->set_border_width( 6 ) ;
+	hbox ->pack_start( treeview_filesystems ) ;
+	get_vbox() ->pack_start( *hbox ) ;
+	
+	//legend..
+	hbox = manage( new Gtk::HBox() ) ;
+	image = manage( new Gtk::Image( Gtk::Stock::APPLY, Gtk::ICON_SIZE_LARGE_TOOLBAR ) );
+	hbox ->pack_start( *image, Gtk::PACK_SHRINK ) ;
+	hbox ->pack_start( * Utils::mk_label( _("Available") ), Gtk::PACK_EXPAND_WIDGET ) ;
+	get_vbox() ->pack_start( *hbox ) ;
+
+	hbox = manage( new Gtk::HBox() ) ;
+	image = manage( new Gtk::Image( Gtk::Stock::CANCEL, Gtk::ICON_SIZE_LARGE_TOOLBAR ) );
+	hbox ->pack_start( *image, Gtk::PACK_SHRINK ) ;
+	hbox ->pack_start( * Utils::mk_label( _("Not Available") ), Gtk::PACK_EXPAND_WIDGET ) ;
+	get_vbox() ->pack_start( *hbox ) ;
 
 	//initialize icons
 	icon_yes = render_icon( Gtk::Stock::APPLY, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ; 
@@ -73,6 +93,7 @@ void DialogFeatures::show_filesystem( const FS & fs )
 	treerow[ treeview_filesystems_columns .move ] = fs .move ? icon_yes : icon_no ;  
 	treerow[ treeview_filesystems_columns .copy ] = fs .copy ? icon_yes : icon_no ; 
 	treerow[ treeview_filesystems_columns .check ] = fs .check ? icon_yes : icon_no ; 
+	treerow[ treeview_filesystems_columns .read_label ] = fs .get_label ? icon_yes : icon_no ; 
 }
 
 DialogFeatures::~DialogFeatures() 
