@@ -33,8 +33,12 @@ Dialog_Progress::Dialog_Progress( const std::vector<Operation *> & operations )
 	this ->operations = operations ;
 	succes = true ;
 	cancel = false ;
+	warnings = 0 ;
 
 	fraction = 1.00 / operations .size() ;
+		
+	dispatcher_update_gui_elements .connect( 
+		sigc::mem_fun( this, &Dialog_Progress::dispatcher_on_update_gui_elements ) ) ;
 			
 	Glib::ustring str_temp = "<span weight=\"bold\" size=\"larger\">" ;
 	str_temp += _("Applying pending operations") ;
@@ -45,53 +49,56 @@ Dialog_Progress::Dialog_Progress( const std::vector<Operation *> & operations )
 	str_temp += "\n";
 	this ->get_vbox() ->pack_start( * Utils::mk_label( str_temp ), Gtk::PACK_SHRINK );
 	
-	this ->get_vbox() ->pack_start( * Utils::mk_label( "<b>" + static_cast<Glib::ustring>( _("Current Operation:") ) + "</b>" ), Gtk::PACK_SHRINK );
-	
+	label_current .set_alignment( Gtk::ALIGN_LEFT );
+	this ->get_vbox() ->pack_start( label_current, Gtk::PACK_SHRINK ) ;
+
 	progressbar_current .set_pulse_step( 0.01 ) ;
 	this->get_vbox() ->pack_start( progressbar_current, Gtk::PACK_SHRINK );
 	
-	label_current .set_alignment( Gtk::ALIGN_LEFT );
-	this ->get_vbox() ->pack_start( label_current, Gtk::PACK_SHRINK );
+	label_current_sub .set_alignment( Gtk::ALIGN_LEFT );
+	this ->get_vbox() ->pack_start( label_current_sub, Gtk::PACK_SHRINK );
 	
-	this ->get_vbox() ->pack_start( * Utils::mk_label( "<b>" + static_cast<Glib::ustring>( _("Completed Operations:") ) + "</b>" ), Gtk::PACK_SHRINK );
+	this ->get_vbox() ->pack_start( * Utils::mk_label( "<b>" + Glib::ustring( _("Completed Operations:") ) + "</b>" ),
+					Gtk::PACK_SHRINK );
 	this ->get_vbox() ->pack_start( progressbar_all, Gtk::PACK_SHRINK );
 	
 	//create some icons here, instead of recreating them every time
 	icon_execute = render_icon( Gtk::Stock::EXECUTE, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
 	icon_succes = render_icon( Gtk::Stock::APPLY, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
 	icon_error = render_icon( Gtk::Stock::DIALOG_ERROR, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
+	icon_info = render_icon( Gtk::Stock::INFO, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
+	icon_n_a = render_icon( Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
 	
 	treestore_operations = Gtk::TreeStore::create( treeview_operations_columns );
 	treeview_operations .set_model( treestore_operations );
 	treeview_operations .set_headers_visible( false );
-	treeview_operations .append_column( "", treeview_operations_columns .operation_icon );
-	treeview_operations .append_column( "", treeview_operations_columns .operation_description );
-	treeview_operations .append_column( "", treeview_operations_columns .status_icon );
-	treeview_operations .set_size_request( 500, 250 ) ;
 	treeview_operations .set_rules_hint( true ) ;
+	treeview_operations .set_size_request( 500, 250 ) ;
+	treeview_operations .append_column( "", treeview_operations_columns .operation_description );
+	treeview_operations .append_column( "", treeview_operations_columns .elapsed_time );
+	treeview_operations .append_column( "", treeview_operations_columns .status_icon );
+
+	treeview_operations .get_column( 0 ) ->set_expand( true ) ;
+	treeview_operations .get_column( 0 ) ->set_cell_data_func( 
+		* ( treeview_operations .get_column( 0 ) ->get_first_cell_renderer() ),
+		sigc::mem_fun(*this, &Dialog_Progress::on_cell_data_description) ) ;
 
 	//fill 'er up
 	for ( unsigned int t = 0 ; t < operations .size() ; t++ )
 	{
-		this ->operations[ t ] ->operation_details .description = "<b>" + operations[ t ] ->description + "</b>" ;
+		this ->operations[ t ] ->operation_detail .set_description( operations[ t ] ->description, FONT_BOLD ) ;
+		this ->operations[ t ] ->operation_detail .set_treepath( Utils::num_to_str( t ) ) ;
 		
 		treerow = *( treestore_operations ->append() );
-		treerow[ treeview_operations_columns .operation_icon ] = operations[ t ] ->icon ;
 		treerow[ treeview_operations_columns .operation_description ] =
-			this ->operations[ t ] ->operation_details .description ; 
-		treerow[ treeview_operations_columns .hidden_status ] = OperationDetails::NONE ; 
+			this ->operations[ t ] ->operation_detail .get_description() ; 
 	}
 	
-	treeview_operations .get_column( 1 ) ->set_expand( true ) ;
-	treeview_operations .get_column( 1 ) ->set_cell_data_func( 
-		* ( treeview_operations .get_column( 1 ) ->get_first_cell_renderer() ),
-		sigc::mem_fun(*this, &Dialog_Progress::on_cell_data_description) ) ;
-	
 	scrolledwindow .set_shadow_type( Gtk::SHADOW_ETCHED_IN ) ;
 	scrolledwindow .set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC ) ;
 	scrolledwindow .add( treeview_operations ) ;
 
-	expander_details .set_label( "<b>" + static_cast<Glib::ustring>( _("Details") ) + "</b>" ) ;
+	expander_details .set_label( "<b>" + Glib::ustring( _("Details") ) + "</b>" ) ;
 	expander_details .set_use_markup( true ) ;
 	expander_details .property_expanded() .signal_changed() .connect(
    		sigc::mem_fun(*this, &Dialog_Progress::on_expander_changed) );
@@ -106,78 +113,108 @@ Dialog_Progress::Dialog_Progress( const std::vector<Operation *> & operations )
 	this ->show_all_children() ;
 }
 
-void Dialog_Progress::update_operation_details( const Gtk::TreeRow & treerow, 
-					        const OperationDetails & operation_details ) 
+void Dialog_Progress::on_signal_update( const OperationDetail & operationdetail ) 
 {
-	//append new rows (if any)
-	for ( unsigned int t = treerow .children() .size() ; t < operation_details .sub_details .size() ; t++ )
-	{
-		Gtk::TreeRow treerow_child = *( treestore_operations ->append( treerow .children() ) ) ;
-		
-		treerow_child[ treeview_operations_columns .operation_description ] =
-			operation_details .sub_details[ t ] .description ;
-		
-		treerow_child[ treeview_operations_columns .hidden_status ] = OperationDetails::NONE ;
-	}
-	
-	//check status and update if necessary
-	if ( operation_details .status != treerow[ treeview_operations_columns .hidden_status ] )
-	{
-		treerow[ treeview_operations_columns .hidden_status ] =	operation_details .status ;
+	Gtk::TreeModel::iterator iter = treestore_operations ->get_iter( operationdetail .get_treepath() ) ;
 
-		switch ( operation_details .status )
+	//i added the second check after get_iter() in gtk+-2.10 seems to behave differently from gtk+-2.8 
+	if ( iter && treestore_operations ->get_string( iter ) == operationdetail .get_treepath() )
+	{
+		Gtk::TreeRow treerow = *iter ;
+
+		treerow[ treeview_operations_columns .operation_description ] = operationdetail .get_description() ;
+		treerow[ treeview_operations_columns .elapsed_time ] = operationdetail .get_elapsed_time() ;
+
+		switch ( operationdetail .get_status() )
 		{
-			case OperationDetails::EXECUTE:
+			case STATUS_EXECUTE:
 				treerow[ treeview_operations_columns .status_icon ] = icon_execute ;
-					
 				break ;
-			case OperationDetails::SUCCES:
+			case STATUS_SUCCES:
 				treerow[ treeview_operations_columns .status_icon ] = icon_succes ;
-				
 				break ;
-			case OperationDetails::ERROR:
+			case STATUS_ERROR:
 				treerow[ treeview_operations_columns .status_icon ] = icon_error ;
-				
 				break ;
-					
-			default : 
-				treerow[ treeview_operations_columns .hidden_status ] = OperationDetails::NONE ;
+			case STATUS_INFO:
+				treerow[ treeview_operations_columns .status_icon ] = icon_info ;
+				break ;
+			case STATUS_N_A:
+				treerow[ treeview_operations_columns .status_icon ] = icon_n_a ;
+				warnings++ ;
+				break ;
+			case STATUS_NONE:
+				static_cast< Glib::RefPtr<Gdk::Pixbuf> >(
+					treerow[ treeview_operations_columns .status_icon ] ) .clear() ;
 				break ;
 		}
-	}
 
-	//and update the children..
-	for ( unsigned int t = 0 ; t < operation_details .sub_details .size() ; t++ )
-		update_operation_details( treerow .children()[ t ], operation_details .sub_details[ t ] ) ;
+		pulse = operationdetail .fraction < 0 ;
+
+		//update the gui elements..
+		this ->operationdetail = operationdetail ;
+
+		if ( operationdetail .get_status() == STATUS_EXECUTE )
+			label_current_sub_text = operationdetail .get_description() ;
+
+		dispatcher_update_gui_elements() ;
+	}
+	else//it's an new od which needs to be added to the model.
+	{
+		unsigned int pos = operationdetail .get_treepath() .rfind( ":" ) ;
+		if ( pos >= 0 && pos < operationdetail .get_treepath() .length() )
+			iter = treestore_operations ->get_iter( operationdetail .get_treepath() 
+							.substr( 0, operationdetail .get_treepath() .rfind( ":" ) ) ) ;
+		else
+			iter = treestore_operations ->get_iter( operationdetail .get_treepath() ) ;
+
+		if ( iter)
+		{
+			treestore_operations ->append( static_cast<Gtk::TreeRow>( *iter) .children() ) ;
+			on_signal_update( operationdetail ) ;
+		}
+	}
+}
+
+void Dialog_Progress::dispatcher_on_update_gui_elements()
+{
+	label_current_sub .set_markup( "<i>" + label_current_sub_text + "</i>\n" ) ;
+	
+	if ( operationdetail .fraction >= 0 )
+	{
+		progressbar_current .set_fraction( operationdetail .fraction > 1.0 ? 1.0 : operationdetail .fraction ) ;
+		progressbar_current .set_text( operationdetail .progress_text ) ;
+	}
 }
 
 void Dialog_Progress::on_signal_show()
 {
 	for ( t = 0 ; t < operations .size() && succes && ! cancel ; t++ )
 	{
-		label_current .set_markup( "<i>" + operations[ t ] ->description + "</i>\n" ) ;
+		operations[ t ] ->operation_detail .signal_update .connect(
+			sigc::mem_fun( this, &Dialog_Progress::on_signal_update ) ) ;
+
+		label_current .set_markup( "<b>" + operations[ t ] ->description + "</b>" ) ;
 		
 		progressbar_all .set_text( String::ucompose( _("%1 of %2 operations completed"), t, operations .size() ) ) ;
-		progressbar_all .set_fraction( fraction * t ) ;
+		progressbar_all .set_fraction( fraction * t > 1.0 ? 1.0 : fraction * t ) ;
 		
 		treerow = treestore_operations ->children()[ t ] ;
 
 		//set status to 'execute'
-		operations[ t ] ->operation_details .status = OperationDetails::EXECUTE ;
-		update_operation_details( treerow, operations[ t ] ->operation_details ) ;
+		operations[ t ] ->operation_detail .set_status( STATUS_EXECUTE ) ;
 
 		//set focus...
 		treeview_operations .set_cursor( static_cast<Gtk::TreePath>( treerow ) ) ;
 		
 		//and start..
-		pulse = true ;
+		running = true ;
 		pthread_create( & pthread, NULL, Dialog_Progress::static_pthread_apply_operation, this );
-	
-		while ( pulse )
-		{
-			update_operation_details( treerow, operations[ t ] ->operation_details ) ;
 
-			progressbar_current .pulse() ;
+		while ( running )
+		{
+			if ( pulse )
+				progressbar_current .pulse() ;
 			
 			while ( Gtk::Main::events_pending() )
 				Gtk::Main::iteration();
@@ -186,9 +223,7 @@ void Dialog_Progress::on_signal_show()
 		}
 
 		//set status (succes/error) for this operation
-		operations[ t ] ->operation_details .status =
-			succes ? OperationDetails::SUCCES : OperationDetails::ERROR ;
-		update_operation_details( treerow, operations[ t ] ->operation_details ) ;
+		operations[ t ] ->operation_detail .set_status( succes ? STATUS_SUCCES : STATUS_ERROR ) ;
 	}
 	
 	//add save button
@@ -207,16 +242,20 @@ void Dialog_Progress::on_signal_show()
 	else
 	{
 		//hide 'current operation' stuff
-		children = this ->get_vbox() ->get_children() ;
-		children[ 1 ] ->hide() ;
-		progressbar_current .hide() ;
 		label_current .hide() ;
+		progressbar_current .hide() ;
+		label_current_sub .hide() ;
 	}
 
 	//deal with succes/error...
 	if ( succes )
 	{
-		progressbar_all .set_text( _("All operations succesfully completed") ) ;
+		str_temp = _("All operations succesfully completed") ;
+
+		if ( warnings > 0 )
+			str_temp += " (" + String::ucompose( _("%1 warnings"), warnings ) + ")" ;
+
+		progressbar_all .set_text( str_temp ) ;
 		progressbar_all .set_fraction( 1.0 ) ;
 	}
 	else 
@@ -231,11 +270,11 @@ void Dialog_Progress::on_signal_show()
 						   Gtk::MESSAGE_ERROR,
 						   Gtk::BUTTONS_OK,
 						   true ) ;
-			str_temp = _("The following operation could not be applied to disk:") ;
-			str_temp += "\n\n<i>" ;
-			str_temp += label_current .get_text() ;
-			str_temp += "</i>\n" ;
-			str_temp += _("See the details for more information") ;
+			str_temp = _("See the details for more information.") ;
+			str_temp += "\n\n<i><b>" + Glib::ustring( _("IMPORTANT") ) + "</b>\n" ;
+			str_temp += _("If you want support, you need to provide the saved details!") ;
+			str_temp += "\n" + String::ucompose( 
+				_("See %1 for more information."), "http://gparted.sourceforge.net/larry/tips/save_details.htm" ) + "</i>" ;
 		
 			dialog .set_secondary_text( str_temp, true ) ;
 			dialog .run() ;
@@ -249,7 +288,7 @@ void Dialog_Progress::on_expander_changed()
 }
 
 void Dialog_Progress::on_cell_data_description( Gtk::CellRenderer * renderer, const Gtk::TreeModel::iterator & iter )
-{//FIXME: markup tags in the text should be escaped (e.g. <device> will interfere with the real tags)
+{
 	dynamic_cast<Gtk::CellRendererText *>( renderer ) ->property_markup() = 
 		static_cast<Gtk::TreeRow>( *iter )[ treeview_operations_columns .operation_description ] ;
 }
@@ -260,7 +299,7 @@ void * Dialog_Progress::static_pthread_apply_operation( void * p_dialog_progress
 	
 	dp ->succes = dp ->signal_apply_operation .emit( dp ->operations[ dp ->t ] ) ;
 	
-	dp ->pulse = false ;
+	dp ->running = false ;
 
 	return NULL ;
 }
@@ -283,7 +322,7 @@ void Dialog_Progress::on_cancel()
 	{
 		pthread_cancel( pthread ) ;
 		cancel = true ;
-		pulse = false ;
+		running = false ;
 		succes = false ;
 	}
 }
@@ -294,7 +333,7 @@ void Dialog_Progress::on_save()
 	dialog .set_transient_for( *this ) ;
 	dialog .set_current_folder( Glib::get_home_dir() ) ;
 	dialog .set_current_name( "gparted_details.htm" ) ;
-//	dialog .set_do_overwrite_confirmation( true ) ; FIXME: since gtkmm-2.8.. 
+	dialog .set_do_overwrite_confirmation( true ) ; 
 	dialog .add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL ) ; 
 	dialog .add_button( Gtk::Stock::SAVE, Gtk::RESPONSE_OK ) ; //there's no enum for SAVE
 
@@ -304,9 +343,10 @@ void Dialog_Progress::on_save()
 		if ( out )
 		{
 			out << "GParted " << VERSION << "<BR><BR>" << std::endl ;
+			out << "Libparted " << signal_get_libparted_version .emit() << "<BR><BR>" << std::endl ; 
 			for ( unsigned int t = 0 ; t < operations .size() ; t++ )
 			{
-				echo_operation_details( operations[ t ] ->operation_details, out ) ;
+				echo_operation_details( operations[ t ] ->operation_detail, out ) ;
 				out << "<BR>========================================<BR><BR>" << std::endl ;
 			}
 				
@@ -315,34 +355,42 @@ void Dialog_Progress::on_save()
 	}
 }
 
-void Dialog_Progress::echo_operation_details( const OperationDetails & operation_details, std::ofstream & out ) 
+void Dialog_Progress::echo_operation_details( const OperationDetail & operationdetail, std::ofstream & out ) 
 {
 	//replace '\n' with '<br>'
-	Glib::ustring temp = operation_details .description ;
+	Glib::ustring temp = operationdetail .get_description() ;
 	for ( unsigned int index = temp .find( "\n" ) ; index < temp .length() ; index = temp .find( "\n" ) )
-		temp .replace( index, 1, "<BR>" ) ;
+		temp .replace( index, 1, "<BR />" ) ;
 	
 	//and export everything to some kind of html...
 	out << "<TABLE border=0>" << std::endl ;
 	out << "<TR>" << std::endl ;
 	out << "<TD colspan=2>" << std::endl ;
 	out << temp ;
+	if ( ! operationdetail .get_elapsed_time() .empty() )
+		out << "&nbsp;&nbsp;" << operationdetail .get_elapsed_time() ;
 	
 	//show status...
-	if ( operation_details .status != OperationDetails::NONE )
+	if ( operationdetail .get_status() != STATUS_NONE )
 	{
 		out << "&nbsp;&nbsp;&nbsp;&nbsp;" ;
-		switch ( operation_details .status )
+		switch ( operationdetail .get_status() )
 		{
-			case OperationDetails::EXECUTE:
+			case STATUS_EXECUTE:
 				out << "( EXECUTING )" ;
 				break ;
-			case OperationDetails::SUCCES:
+			case STATUS_SUCCES:
 				out << "( SUCCES )" ;
 				break ;
-			case OperationDetails::ERROR:
+			case STATUS_ERROR:
 				out << "( ERROR )" ;
 				break ;
+			case STATUS_INFO:
+				out << "( INFO )" ;
+				break ;
+			case STATUS_N_A:
+				out << "( N/A )" ;
+				break ;
 
 			default:
 				break ;
@@ -353,19 +401,18 @@ void Dialog_Progress::echo_operation_details( const OperationDetails & operation
 	out << "</TD>" << std::endl ;
 	out << "</TR>" << std::endl ;
 	
-	if ( operation_details .sub_details. size() )
+	if ( operationdetail .get_childs(). size() )
 	{
 		out << "<TR>" << std::endl ;
 		out << "<TD>&nbsp;&nbsp;&nbsp;&nbsp;</TD>" << std::endl ;
 		out << "<TD>" << std::endl ;
 
-		for ( unsigned int t = 0 ; t < operation_details .sub_details .size() ; t++ )
-			echo_operation_details( operation_details .sub_details[ t ], out ) ;
+		for ( unsigned int t = 0 ; t <  operationdetail .get_childs() .size() ; t++ )
+			echo_operation_details( operationdetail .get_childs()[ t ], out ) ;
 
 		out << "</TD>" << std::endl ;
 		out << "</TR>" << std::endl ;
 	}
-	
 	out << "</TABLE>" << std::endl ;
 }
 
