@@ -38,6 +38,8 @@
 #include "../include/ufs.h"
 
 #include <cerrno>
+#include <cstdio>
+#include <csignal>
 #include <sys/statvfs.h>	
 
 std::vector<Glib::ustring> libparted_messages ; //see ped_exception_handler()
@@ -45,6 +47,13 @@ std::vector<Glib::ustring> libparted_messages ; //see ped_exception_handler()
 namespace GParted
 {
 
+// Clean up the fdi when terminating
+void sig_fdi_cleanup( int signum )
+{
+	remove( "/usr/share/hal/fdi/policy/gparted-disable-automount.fdi" );
+	raise( signum );
+}
+
 GParted_Core::GParted_Core() 
 {
 	lp_device = NULL ;
@@ -53,6 +62,29 @@ GParted_Core::GParted_Core()
 	p_filesystem = NULL ;
 
 	ped_exception_set_handler( ped_exception_handler ) ; 
+
+	//make sure that the fdi is cleaned up on all but the most forceful
+	//program exits
+	struct sigaction sa;
+	sa.sa_handler = sig_fdi_cleanup;
+	sigemptyset( &sa.sa_mask );
+	sa.sa_flags = SA_RESETHAND;
+	if( sigaction( SIGHUP, &sa, NULL ) == -1 ||
+	    sigaction( SIGINT, &sa, NULL ) == -1 ||
+	    sigaction( SIGQUIT, &sa, NULL ) == -1 ||
+	    sigaction( SIGILL, &sa, NULL ) == -1 ||
+	    sigaction( SIGABRT, &sa, NULL ) == -1 ||
+	    sigaction( SIGFPE, &sa, NULL ) == -1 ||
+	    sigaction( SIGSEGV, &sa, NULL ) == -1 ||
+	    sigaction( SIGPIPE, &sa, NULL ) == -1 ||
+	    sigaction( SIGALRM, &sa, NULL ) == -1 ||
+	    sigaction( SIGTERM, &sa, NULL ) == -1 ||
+	    sigaction( SIGUSR1, &sa, NULL ) == -1 ||
+	    sigaction( SIGUSR2, &sa, NULL ) == -1 ||
+	    sigaction( SIGBUS, &sa, NULL ) == -1 ||
+	    sigaction( SIGXCPU, &sa, NULL ) == -1 ||
+	    sigaction( SIGXFSZ, &sa, NULL ) == -1 )
+		perror( "Could not set signal handler" );
 	
 	//disable automount //FIXME: temporary hack, till i find a better solution...
 	std::ofstream fdi_file( "/usr/share/hal/fdi/policy/gparted-disable-automount.fdi" ) ;
@@ -60,8 +92,8 @@ GParted_Core::GParted_Core()
 	{
 		fdi_file << "<deviceinfo version='0.2'>" ;
 		fdi_file << "<device>" ;
-		fdi_file << "<match key='@block.storage_device:storage.hotpluggable' bool='true'>" ;
-		fdi_file << "<merge key='volume.ignore' type='bool'>true</merge>" ;
+		fdi_file << "<match key='storage.hotpluggable' bool='true'>" ;
+		fdi_file << "<merge key='storage.automount_enabled_hint' type='bool'>false</merge>" ;
 		fdi_file << "</match>" ;
 		fdi_file << "</device>" ;
 		fdi_file << "</deviceinfo>" ;
@@ -155,7 +187,20 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 		lp_device = ped_device_get_next( NULL );
 		while ( lp_device ) 
 		{
-			device_paths .push_back( lp_device ->path ) ;
+			//only add this device if we can read the first sector (which means it's a real device)
+			char * buf = static_cast<char *>( malloc( lp_device ->sector_size ) ) ;
+			if ( buf )
+			{
+				if ( ped_device_open( lp_device ) )
+				{
+					if ( ped_device_read( lp_device, buf, 0, 1 ) )
+						device_paths .push_back( lp_device ->path ) ;
+
+					ped_device_close( lp_device ) ;
+				}
+
+				free( buf ) ;
+			}
 			
 			lp_device = ped_device_get_next( lp_device ) ;
 		}
@@ -163,10 +208,10 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 
 		std::sort( device_paths .begin(), device_paths .end() ) ;
 	}
-	
+
 	for ( unsigned int t = 0 ; t < device_paths .size() ; t++ ) 
 	{ 
-		if ( device_paths[ t ] .length() > 6 && device_paths[ t ] .is_ascii() && open_device_and_disk( device_paths[ t ], false ) )
+		if ( open_device_and_disk( device_paths[ t ], false ) )
 		{
 			temp_device .Reset() ;
 			
@@ -180,7 +225,7 @@ void GParted_Core::set_devices( std::vector<Device> & devices )
 			temp_device .cylinders	=	lp_device ->bios_geom .cylinders ;
 			temp_device .length 	=	temp_device .heads * temp_device .sectors * temp_device .cylinders ;
 			temp_device .cylsize 	=	temp_device .heads * temp_device .sectors ; 
-			
+		
 			//make sure cylsize is at least 1 MiB
 			if ( temp_device .cylsize < MEBIBYTE )
 				temp_device .cylsize = MEBIBYTE ;
