@@ -34,6 +34,7 @@ TreeView_Detail::TreeView_Detail()
 	append_column( _("Partition"), treeview_detail_columns .path );
 	append_column( _("Filesystem"), treeview_detail_columns .color );
 	append_column( _("Mountpoint"), treeview_detail_columns .mountpoint );
+	append_column( _("Label"), treeview_detail_columns .label );
 	append_column( _("Size"), treeview_detail_columns .size );
 	append_column( _("Used"), treeview_detail_columns .used );
 	append_column( _("Unused"), treeview_detail_columns .unused );
@@ -71,11 +72,11 @@ TreeView_Detail::TreeView_Detail()
 					 treeview_detail_columns .mount_text_color );
 
 	//set alignment of numeric columns to right
-	for( short t = 3 ; t < 6 ; t++ )
+	for( short t = 4 ; t < 7 ; t++ )
 		get_column_cell_renderer( t ) ->property_xalign() = 1 ;
 
 	//expand columns and centeralign the headertext
-	for( short t = 3 ; t < 7 ; t++ )
+	for( short t = 4 ; t < 8 ; t++ )
 	{
 		get_column( t ) ->set_expand( true ) ;
 		get_column( t ) ->set_alignment( 0.5 ) ;
@@ -84,31 +85,13 @@ TreeView_Detail::TreeView_Detail()
 
 void TreeView_Detail::load_partitions( const std::vector<Partition> & partitions ) 
 {
-	bool mount_info = false ;
+	bool mountpoints = false, labels = false ;
 	treestore_detail ->clear() ;
 	
-	for ( unsigned int i = 0 ; i < partitions .size() ; i++ ) 
-	{	
-		row = *( treestore_detail ->append() );
-		create_row( row, partitions[ i ] );
-		
-		if ( partitions[ i ] .type == GParted::TYPE_EXTENDED )
-		{
-			for ( unsigned int t = 0 ; t < partitions[ i ] .logicals .size() ; t++ ) 
-			{
-				childrow = *( treestore_detail ->append( row.children() ) );
-				create_row( childrow, partitions[ i ] .logicals[ t ] );
-		
-				if ( partitions[ i ] .logicals[ t ] .get_mountpoints() .size() )
-					mount_info = true ;
-			}
-		}
+	load_partitions( partitions, mountpoints, labels ) ;
 
-		if ( partitions[ i ] .get_mountpoints() .size() )
-			mount_info = true ;
-	}
-
-	get_column( 2 ) ->set_visible( mount_info ) ;
+	get_column( 2 ) ->set_visible( mountpoints ) ;
+	get_column( 3 ) ->set_visible( labels ) ;
 	
 	columns_autosize();
 	expand_all() ;
@@ -126,6 +109,28 @@ void TreeView_Detail::clear()
 	treestore_detail ->clear() ;
 }
 
+void TreeView_Detail::load_partitions( const std::vector<Partition> & partitions,
+				       bool & mountpoints,
+				       bool & labels,
+				       const Gtk::TreeRow & parent_row ) 
+{
+	Gtk::TreeRow row ;
+	for ( unsigned int i = 0 ; i < partitions .size() ; i++ ) 
+	{	
+		row = parent_row ? *( treestore_detail ->append( parent_row .children() ) ) : *( treestore_detail ->append() ) ;
+		create_row( row, partitions[ i ] );
+		
+		if ( partitions[ i ] .type == GParted::TYPE_EXTENDED )
+			load_partitions( partitions[ i ] .logicals, mountpoints, labels, row ) ;
+			
+		if ( partitions[ i ] .get_mountpoints() .size() )
+			mountpoints = true ;
+					
+		if ( ! partitions[ i ] .label .empty() )
+			labels = true ;
+	}
+}
+
 bool TreeView_Detail::set_selected( Gtk::TreeModel::Children rows, const Partition & partition, bool inside_extended ) 
 {
 	for ( unsigned int t = 0 ; t < rows .size() ; t++ )
@@ -138,8 +143,8 @@ bool TreeView_Detail::set_selected( Gtk::TreeModel::Children rows, const Partiti
 			set_cursor( static_cast<Gtk::TreePath>( rows[ t ] ) ) ;
 			return true ;
 		}
-		
-		if ( rows[ t ] .children() .size() > 0 && set_selected( rows[ t ] .children(), partition, true ) )
+
+		if ( set_selected( rows[ t ] .children(), partition, true ) )
 			return true ;
 	}
 	
@@ -152,7 +157,7 @@ void TreeView_Detail::create_row( const Gtk::TreeRow & treerow, const Partition
 		treerow[ treeview_detail_columns .icon1 ] = 
 			render_icon( Gtk::Stock::DIALOG_AUTHENTICATION, Gtk::ICON_SIZE_BUTTON );
 	
-	if ( ! partition .error .empty() )
+	if ( partition .messages .size() > 0 )
 	{
 		if ( ! static_cast< Glib::RefPtr<Gdk::Pixbuf> >( treerow[ treeview_detail_columns .icon1 ] )  )
 			treerow[ treeview_detail_columns .icon1 ] = 
@@ -180,6 +185,8 @@ void TreeView_Detail::create_row( const Gtk::TreeRow & treerow, const Partition
 	//mountpoint
 	treerow[ treeview_detail_columns .mount_text_color ] = partition .busy ? "black" : "darkgrey" ;
 	treerow[ treeview_detail_columns .mountpoint ] = Glib::build_path( ", ", partition .get_mountpoints() ) ;
+
+	treerow[ treeview_detail_columns .label ] = partition .label ;
 		
 	//size
 	treerow[ treeview_detail_columns .size ] = Utils::format_size( partition .get_length() ) ;
@@ -224,7 +231,7 @@ void TreeView_Detail::on_selection_changed()
 {
 	if ( ! block && treeselection ->get_selected() != 0 )
 	{
-		row = static_cast<Gtk::TreeRow>( * treeselection ->get_selected() ) ;
+		Gtk::TreeRow row = static_cast<Gtk::TreeRow>( * treeselection ->get_selected() ) ;
 		signal_partition_selected .emit( row[ treeview_detail_columns .partition ], true ) ;
 	}
 }
