@@ -41,8 +41,7 @@ FS fat16::get_filesystem_support()
 	fs .shrink = GParted::FS::LIBPARTED ;
 	fs .move = GParted::FS::LIBPARTED ;
 		
-	if ( ! Glib::find_program_in_path( "dd" ) .empty() )
-		fs .copy = GParted::FS::EXTERNAL ;
+	fs .copy = GParted::FS::GPARTED ;
 	
 	fs .MIN = 16 * MEBIBYTE ;
 	fs .MAX = 4096 * MEBIBYTE ;
@@ -50,10 +49,10 @@ FS fat16::get_filesystem_support()
 	return fs ;
 }
 
-void fat16::Set_Used_Sectors( Partition & partition ) 
+void fat16::set_used_sectors( Partition & partition ) 
 {
 	exit_status = Utils::execute_command( "dosfsck -a -v " + partition .get_path(), output, error, true ) ;
-	if ( exit_status == 0 || exit_status == 1 )
+	if ( exit_status == 0 || exit_status == 1 || exit_status == 256 )
 	{
 		//free clusters
 		index = output .find( ",", output .find( partition .get_path() ) + partition .get_path() .length() ) +1 ;
@@ -71,72 +70,41 @@ void fat16::Set_Used_Sectors( Partition & partition )
 			partition .Set_Unused( Utils::round( N * ( S / 512.0 ) ) ) ;
 	}
 	else
-		partition .error = error ;
-}
-	
-bool fat16::Create( const Partition & new_partition, std::vector<OperationDetails> & operation_details )
-{
-	operation_details .push_back( OperationDetails( String::ucompose(
-								_("create new %1 filesystem"),
-								Utils::get_filesystem_string( GParted::FS_FAT16 ) ) ) ) ;
-	
-	if ( ! execute_command( "mkdosfs -F16 -v " + new_partition .get_path(), operation_details .back() .sub_details ) )
 	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;
-	}
-	else
-	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
+		if ( ! output .empty() )
+			partition .messages .push_back( output ) ;
+		
+		if ( ! error .empty() )
+			partition .messages .push_back( error ) ;
 	}
 }
 
-bool fat16::Resize( const Partition & partition_new,
-		    std::vector<OperationDetails> & operation_details,
-		    bool fill_partition )
+void fat16::get_label( Partition & partition )
+{
+}
+	
+bool fat16::create( const Partition & new_partition, OperationDetail & operationdetail )
+{
+	return ! execute_command( "mkdosfs -F16 -v " + new_partition .get_path(), operationdetail ) ;
+}
+
+bool fat16::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	return true ;
 }
 
-bool fat16::Copy( const Glib::ustring & src_part_path,
+bool fat16::copy( const Glib::ustring & src_part_path,
 		  const Glib::ustring & dest_part_path,
-		  std::vector<OperationDetails> & operation_details )
+		  OperationDetail & operationdetail )
 {
-	operation_details .push_back( OperationDetails( 
-				String::ucompose( _("copy contents of %1 to %2"), src_part_path, dest_part_path ) ) ) ;
-	
-	if ( ! execute_command( "dd bs=8192 if=" + src_part_path + " of=" + dest_part_path,
-				 operation_details .back() .sub_details ) )
-	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;	
-	}
-	else
-	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
-	}
+	return true ;
 }
 
-bool fat16::Check_Repair( const Partition & partition, std::vector<OperationDetails> & operation_details )
+bool fat16::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	operation_details .push_back( OperationDetails( 
-				String::ucompose( _("check filesystem on %1 for errors and (if possible) fix them"),
-						  partition .get_path() ) ) ) ;
+	exit_status = execute_command( "dosfsck -a -w -v " + partition .get_path(), operationdetail ) ;
 
-	exit_status = execute_command( "dosfsck -a -w -v " + partition .get_path(),
-				   operation_details .back() .sub_details ) ;
-	if ( exit_status == 0 || exit_status == 1 )
-	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;
-	}
-	else
-	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
-	}
+	return ( exit_status == 0 || exit_status == 1 || exit_status == 256 ) ;
 }
 
 } //GParted
