@@ -41,18 +41,18 @@ FS fat32::get_filesystem_support()
 	fs .shrink = GParted::FS::LIBPARTED ;
 	fs .move = GParted::FS::LIBPARTED ;
 		
-	if ( ! Glib::find_program_in_path( "dd" ) .empty() )
-		fs .copy = GParted::FS::EXTERNAL ;
+	fs .copy = GParted::FS::GPARTED ;
 	
 	fs .MIN = 32 * MEBIBYTE ; //smaller fs'es will cause windows scandisk to fail..
 	
 	return fs ;
 }
 
-void fat32::Set_Used_Sectors( Partition & partition ) 
+void fat32::set_used_sectors( Partition & partition ) 
 {
+	//FIXME: i've encoutered a readonly fat32 filesystem.. this won't work with the -a ... best check also without the -a
 	exit_status = Utils::execute_command( "dosfsck -a -v " + partition .get_path(), output, error, true ) ;
-	if ( exit_status == 0 || exit_status == 1 )
+	if ( exit_status == 0 || exit_status == 1 || exit_status == 256 )
 	{
 		//free clusters
 		index = output .find( ",", output .find( partition .get_path() ) + partition .get_path() .length() ) +1 ;
@@ -70,72 +70,41 @@ void fat32::Set_Used_Sectors( Partition & partition )
 			partition .Set_Unused( Utils::round( N * ( S / 512.0 ) ) ) ;
 	}
 	else
-		partition .error = error ;
+	{
+		if ( ! output .empty() )
+			partition .messages .push_back( output ) ;
+		
+		if ( ! error .empty() )
+			partition .messages .push_back( error ) ;
+	}
 }
 
-bool fat32::Create( const Partition & new_partition, std::vector<OperationDetails> & operation_details )
+void fat32::get_label( Partition & partition )
 {
-	operation_details .push_back( OperationDetails( String::ucompose(
-								_("create new %1 filesystem"),
-								Utils::get_filesystem_string( GParted::FS_FAT32 ) ) ) ) ;
-	
-	if ( ! execute_command( "mkdosfs -F32 -v " + new_partition .get_path(), operation_details .back() .sub_details ) )
-	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;
-	}
-	else
-	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
-	}
 }
 
-bool fat32::Resize( const Partition & partition_new,
-		    std::vector<OperationDetails> & operation_details,
-		    bool fill_partition )
+bool fat32::create( const Partition & new_partition, OperationDetail & operationdetail )
+{
+	return ! execute_command( "mkdosfs -F32 -v " + new_partition .get_path(), operationdetail ) ;
+}
+
+bool fat32::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	return true ;
 }
 
-bool fat32::Copy( const Glib::ustring & src_part_path, 
+bool fat32::copy( const Glib::ustring & src_part_path, 
 		  const Glib::ustring & dest_part_path,
-		  std::vector<OperationDetails> & operation_details )
+		  OperationDetail & operationdetail )
 {
-	operation_details .push_back( OperationDetails( 
-				String::ucompose( _("copy contents of %1 to %2"), src_part_path, dest_part_path ) ) ) ;
-	
-	if ( ! execute_command( "dd bs=8192 if=" + src_part_path + " of=" + dest_part_path,
-				 operation_details .back() .sub_details ) )
-	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;	
-	}
-	else
-	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
-	}
+	return true ;
 }
 
-bool fat32::Check_Repair( const Partition & partition, std::vector<OperationDetails> & operation_details )
+bool fat32::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	operation_details .push_back( OperationDetails( 
-				String::ucompose( _("check filesystem on %1 for errors and (if possible) fix them"),
-						  partition .get_path() ) ) ) ;
-	
-	exit_status = execute_command( "dosfsck -a -w -v " + partition .get_path(),
-				       operation_details .back() .sub_details ) ;
-	if ( exit_status == 0 || exit_status == 1 )
-	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;
-	}
-	else
-	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
-	}
+	exit_status = execute_command( "dosfsck -a -w -v " + partition .get_path(), operationdetail ) ;
+
+	return ( exit_status == 0 || exit_status == 1 || exit_status == 256 ) ;
 }
 
 } //GParted
