@@ -27,7 +27,10 @@ FS reiser4::get_filesystem_support()
 	fs .filesystem = GParted::FS_REISER4 ;
 	
 	if ( ! Glib::find_program_in_path( "debugfs.reiser4" ) .empty() )
+	{
 		fs .read = GParted::FS::EXTERNAL ;
+		fs .get_label = FS::EXTERNAL ;
+	}
 	
 	if ( ! Glib::find_program_in_path( "mkfs.reiser4" ) .empty() )
 		fs .create = GParted::FS::EXTERNAL ;
@@ -35,8 +38,12 @@ FS reiser4::get_filesystem_support()
 	if ( ! Glib::find_program_in_path( "fsck.reiser4" ) .empty() )
 		fs .check = GParted::FS::EXTERNAL ;
 	
-	if ( ! Glib::find_program_in_path( "dd" ) .empty() )
-		fs .copy = GParted::FS::EXTERNAL ;
+
+	if ( fs .check )
+	{
+		fs .copy = GParted::FS::GPARTED ;
+		fs .move = GParted::FS::GPARTED ;
+	}
 	
 	/*
 	 * IT SEEMS RESIZE AND COPY AREN'T IMPLEMENTED YET IN THE TOOLS...
@@ -46,7 +53,7 @@ FS reiser4::get_filesystem_support()
 	return fs ;
 }
 
-void reiser4::Set_Used_Sectors( Partition & partition ) 
+void reiser4::set_used_sectors( Partition & partition ) 
 {
 	if ( ! Utils::execute_command( "debugfs.reiser4 " + partition .get_path(), output, error, true ) )
 	{
@@ -64,71 +71,58 @@ void reiser4::Set_Used_Sectors( Partition & partition )
 			partition .Set_Unused( Utils::round( N * ( S / 512.0 ) ) ) ;
 	}
 	else
-		partition .error = error ;
+	{
+		if ( ! output .empty() )
+			partition .messages .push_back( output ) ;
+		
+		if ( ! error .empty() )
+			partition .messages .push_back( error ) ;
+	}
 }
 
-bool reiser4::Create( const Partition & new_partition, std::vector<OperationDetails> & operation_details )
+void reiser4::get_label( Partition & partition )
 {
-	operation_details .push_back( OperationDetails( String::ucompose(
-								_("create new %1 filesystem"),
-								Utils::get_filesystem_string( GParted::FS_REISER4 ) ) ) ) ;
-	
-	if ( ! execute_command( "mkfs.reiser4 --yes " + new_partition .get_path(), operation_details .back() .sub_details ) )
+	if ( ! Utils::execute_command( "debugfs.reiser4 " + partition .get_path(), output, error, true ) )
 	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;
+		char buf[512] ;
+		index = output .find( "label" ) ;
+
+		//FIXME: find a better way to see if label is empty.. imagine someone uses '<none>' as label.... ;)
+		if ( index < output .length() && 
+		     sscanf( output .substr( index ) .c_str(), "label: %512s", buf ) == 1 &&
+		     Glib::ustring( buf ) != "<none>" )
+			partition .label = buf ;
 	}
 	else
 	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
+		if ( ! output .empty() )
+			partition .messages .push_back( output ) ;
+		
+		if ( ! error .empty() )
+			partition .messages .push_back( error ) ;
 	}
 }
 
-bool reiser4::Resize( const Partition & partition_new,
-		      std::vector<OperationDetails> & operation_details,
-		      bool fill_partition )
+bool reiser4::create( const Partition & new_partition, OperationDetail & operationdetail )
+{
+	return ! execute_command( "mkfs.reiser4 --yes " + new_partition .get_path(), operationdetail ) ;
+}
+
+bool reiser4::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	return true ;
 }
 
-bool reiser4::Copy( const Glib::ustring & src_part_path, 
+bool reiser4::copy( const Glib::ustring & src_part_path, 
 		    const Glib::ustring & dest_part_path,
-		    std::vector<OperationDetails> & operation_details )
+		    OperationDetail & operationdetail )
 {
-	operation_details .push_back( OperationDetails( 
-				String::ucompose( _("copy contents of %1 to %2"), src_part_path, dest_part_path ) ) ) ;
-
-	if ( ! execute_command( "dd bs=8192 if=" + src_part_path + " of=" + dest_part_path,
-				 operation_details .back() .sub_details ) )
-	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;	
-	}
-	else
-	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
-	}
+	return true ;
 }
 
-bool reiser4::Check_Repair( const Partition & partition, std::vector<OperationDetails> & operation_details )
+bool reiser4::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
-	operation_details .push_back( OperationDetails( 
-				String::ucompose( _("check filesystem on %1 for errors and (if possible) fix them"),
-						  partition .get_path() ) ) ) ;
-	
-	if ( ! execute_command( "fsck.reiser4 --yes --fix " + partition .get_path(),
-				operation_details .back() .sub_details ) )
-	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;
-	}
-	else
-	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
-	}
+	return ! execute_command( "fsck.reiser4 --yes --fix --quiet " + partition .get_path(), operationdetail ) ;
 }
 
 } //GParted
